#
# spec file for package ghc-extra
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name extra
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.8
Release:        1.3
Summary:        Extra functions I use
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-clock-devel
BuildRequires:  ghc-clock-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-quickcheck-instances-devel
BuildRequires:  ghc-quickcheck-instances-prof
%endif

%description
A library of extra functions for the standard Haskell libraries. Most functions
are simple additions, filling out missing functionality. A few functions are
available in later versions of GHC, but this package makes them available back
to GHC 7.2.

The module "Extra" documents all functions provided by this library.
Modules such as "Data.List.Extra" provide extra functions over "Data.List" and
also reexport "Data.List". Users are recommended to replace "Data.List" imports
with "Data.List.Extra" if they need the extra functionality.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.txt README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Nov 19 2024 Peter Simons <psimons@suse.com>
- Update extra to version 1.8.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/extra-1.8/src/CHANGES.txt
* Tue Oct 22 2024 Peter Simons <psimons@suse.com>
- Update extra to version 1.7.16 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat May 11 2024 Peter Simons <psimons@suse.com>
- Update extra to version 1.7.16.
  1.7.16, released 2024-05-11
    Fix to actually work with GHC 9.10
* Fri May 10 2024 Peter Simons <psimons@suse.com>
- Update extra to version 1.7.15.
  1.7.15, released 2024-05-10
    [#111], work with GHC 9.10
    Test with GHC 9.8
* Sat Jul  1 2023 Peter Simons <psimons@suse.com>
- Update extra to version 1.7.14.
  1.7.14, released 2023-07-01
    [#106], add compatibility with GHC 9.7
    [#103], future-proof against addition of Data.List.unsnoc
* Sun Apr  2 2023 Peter Simons <psimons@suse.com>
- Update extra to version 1.7.13.
  1.7.13, released 2023-04-22
    [#102], add mwhen :: Monoid a => Bool -> a -> a
    [#99], make replace with an empty from intersperse the replacement
    [#101], future-proof against addition of Data.List.!?
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Fri Sep  2 2022 Peter Simons <psimons@suse.com>
- Update extra to version 1.7.12.
  1.7.12, released 2022-09-02
    [#98], make both lazy in its argument
    [#98], make first3,second3,third3 lazy in their argument
    [#98], make firstM,secondM lazy in their argument
    [#86], add notNull for Foldable
  1.7.11, released 2022-08-21
    [#95], add List.repeatedlyNE and NonEmpty.repeatedly
    [#94], add groupOnKey
    [#91], add foldl1' to NonEmpty
  1.7.10, released 2021-08-29
    [#81], add assertIO function
    [#85], add !? to do !! list indexing returning a Maybe
    [#80], add strict Var functions modifyVar', modifyVar_', writeVar'
* Tue Sep  7 2021 psimons@suse.com
- Add extra at version 1.7.9.
